Advanced Resources Management
=============================

Provisioning in LinchPin is a fairly simple process.

.. toctree::
   :tocdepth: 1

Managing Credentials
--------------------

.. include:: resources/credentials.rst

Using the Journal
-----------------

.. include:: resources/journal.rst

Dynamic PinFile
---------------

.. include:: resources/dynamic_pinfile.rst

PinFile Templating
------------------

.. include:: resources/pinfile_templating.rst


